Module runtime

Module runtime 

Re-exports

pub use observability::LogFormat;
pub use observability::ObservabilityConfig;
pub use crate::runtime::registry::OrchestrationRegistry;
pub use crate::runtime::registry::OrchestrationRegistryBuilder;
pub use crate::runtime::registry::VersionPolicy;

Modules

execution
observability
Observability infrastructure for metrics and structured logging.
registry
Generic versioned registry for orchestrations and activities
replay_engine

Structs

FnActivity
Function wrapper that implements ActivityHandler.
FnOrchestration
Function wrapper that implements OrchestrationHandler.
HistoryManager
Reader for extracting metadata from orchestration history
OrchestrationDescriptor
Introspection: descriptor of an orchestration derived from history.
Runtime
In-process runtime that executes activities and timers and persists history via a Provider.
RuntimeOptions
Configuration options for the Runtime.
UnregisteredBackoffConfig
Configuration for exponential backoff when encountering unregistered orchestrations/activities.
WorkItemReader
Reader for extracting information from a batch of work items

Enums

OrchestrationStatus
High-level orchestration status derived from history.

Traits

ActivityHandler
Trait implemented by activity handlers that can be invoked by the runtime.
OrchestrationHandler
Trait implemented by orchestration handlers that can be invoked by the runtime.

Functions

kind_of