Re-exports
pub use observability::LogFormat;pub use observability::ObservabilityConfig;pub use crate::runtime::registry::OrchestrationRegistry;pub use crate::runtime::registry::OrchestrationRegistryBuilder;pub use crate::runtime::registry::VersionPolicy;
Modules
- execution
- observability
- Observability infrastructure for metrics and structured logging.
- registry
- Generic versioned registry for orchestrations and activities
- replay_
engine
Structs
- FnActivity
- Function wrapper that implements
ActivityHandler. - FnOrchestration
- Function wrapper that implements
OrchestrationHandler. - History
Manager - Reader for extracting metadata from orchestration history
- Orchestration
Descriptor - Introspection: descriptor of an orchestration derived from history.
- Runtime
- In-process runtime that executes activities and timers and persists
history via a
Provider. - Runtime
Options - Configuration options for the Runtime.
- Unregistered
Backoff Config - Configuration for exponential backoff when encountering unregistered orchestrations/activities.
- Work
Item Reader - Reader for extracting information from a batch of work items
Enums
- Orchestration
Status - High-level orchestration status derived from history.
Traits
- Activity
Handler - Trait implemented by activity handlers that can be invoked by the runtime.
- Orchestration
Handler - Trait implemented by orchestration handlers that can be invoked by the runtime.